@@ -10,22 +10,22 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.09';
-$DATE = '2003/07/05';
+$VERSION = '0.10';
+$DATE = '2003/07/11';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.09 2003/07/05), 'revised 0.08'],
-    'MANIFEST' => [qw(0.09 2003/07/05), 'generated, replaces 0.08'],
-    'Makefile.PL' => [qw(0.09 2003/07/05), 'generated, replaces 0.08'],
-    'README' => [qw(0.09 2003/07/05), 'generated, replaces 0.08'],
-    'lib/Test/Tech.pm' => [qw(1.09 2003/06/24), 'unchanged'],
-    't/Test/Tech/Tech.t' => [qw(0.1 2003/07/05), 'revised 0.09'],
-    't/Test/Tech/techA0.t' => [qw(0.06 2003/07/05), 'revised 0.05'],
+    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.10 2003/07/11), 'revised 0.09'],
+    'MANIFEST' => [qw(0.10 2003/07/11), 'generated, replaces 0.09'],
+    'Makefile.PL' => [qw(0.10 2003/07/11), 'generated, replaces 0.09'],
+    'README' => [qw(0.10 2003/07/11), 'generated, replaces 0.09'],
+    'lib/Test/Tech.pm' => [qw(1.1 2003/07/11), 'revised 1.09'],
+    't/Test/Tech/Tech.t' => [qw(0.1 2003/07/05), 'unchanged'],
+    't/Test/Tech/techA0.t' => [qw(0.06 2003/07/05), 'unchanged'],
     't/Test/Tech/techA2.txt' => [qw(0.05 2003/06/19), 'unchanged'],
-    't/Test/Tech/techB0.t' => [qw(0.03 2003/07/05), 'revised 0.02'],
-    't/Test/Tech/techC0.t' => [qw(0.06 2003/07/05), 'revised 0.05'],
+    't/Test/Tech/techB0.t' => [qw(0.03 2003/07/05), 'unchanged'],
+    't/Test/Tech/techC0.t' => [qw(0.06 2003/07/05), 'unchanged'],
     't/Test/Tech/techC2.txt' => [qw(0.06 2003/06/21), 'unchanged'],
     't/Test/Tech/techC3.txt' => [qw(0.06 2003/06/21), 'unchanged'],
     't/Test/Tech/techD0.d' => [qw(0.02 2003/06/21), 'unchanged'],
@@ -61,9 +61,9 @@ use vars qw(%INVENTORY);
 
  Revision: H
 
- Version: 0.09
+ Version: 0.10
 
- Date: 2003/07/05
+ Date: 2003/07/11
 
  Prepared for: General Public 
 
@@ -172,7 +172,7 @@ and Test::TestUtil has disappeared.
 
 =head2 1.3 Document overview.
 
-This document releases Test::Tech version 0.09
+This document releases Test::Tech version 0.10
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -188,8 +188,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/Test-Tech-0.09
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.09
+   http://www.softwarediamonds/packages/Test-Tech-0.10
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.10
 
 
 Restrictions regarding duplication and license provisions
@@ -257,16 +257,16 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_Tech.pm                               0.09    2003/07/05 revised 0.08
- MANIFEST                                                     0.09    2003/07/05 generated, replaces 0.08
- Makefile.PL                                                  0.09    2003/07/05 generated, replaces 0.08
- README                                                       0.09    2003/07/05 generated, replaces 0.08
- lib/Test/Tech.pm                                             1.09    2003/06/24 unchanged
- t/Test/Tech/Tech.t                                           0.1     2003/07/05 revised 0.09
- t/Test/Tech/techA0.t                                         0.06    2003/07/05 revised 0.05
+ lib/Docs/Site_SVD/Test_Tech.pm                               0.10    2003/07/11 revised 0.09
+ MANIFEST                                                     0.10    2003/07/11 generated, replaces 0.09
+ Makefile.PL                                                  0.10    2003/07/11 generated, replaces 0.09
+ README                                                       0.10    2003/07/11 generated, replaces 0.09
+ lib/Test/Tech.pm                                             1.1     2003/07/11 revised 1.09
+ t/Test/Tech/Tech.t                                           0.1     2003/07/05 unchanged
+ t/Test/Tech/techA0.t                                         0.06    2003/07/05 unchanged
  t/Test/Tech/techA2.txt                                       0.05    2003/06/19 unchanged
- t/Test/Tech/techB0.t                                         0.03    2003/07/05 revised 0.02
- t/Test/Tech/techC0.t                                         0.06    2003/07/05 revised 0.05
+ t/Test/Tech/techB0.t                                         0.03    2003/07/05 unchanged
+ t/Test/Tech/techC0.t                                         0.06    2003/07/05 unchanged
  t/Test/Tech/techC2.txt                                       0.06    2003/06/21 unchanged
  t/Test/Tech/techC3.txt                                       0.06    2003/06/21 unchanged
  t/Test/Tech/techD0.d                                         0.02    2003/06/21 unchanged
@@ -473,16 +473,16 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/Test-Tech-0.09
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.09
+   http://www.softwarediamonds/packages/Test-Tech-0.10
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.10
 
 
 =item Prerequistes.
 
- 'File::SmartNL' => 0,
- 'File::Package' => 0,
- 'File::TestPath' => 0,
- 'Text::Scrub' => 0,
+ 'File::SmartNL' => '0',
+ 'File::Package' => '0',
+ 'File::TestPath' => '0',
+ 'Text::Scrub' => '0',
 
 
 =item Security, privacy, or safety precautions.
@@ -594,10 +594,10 @@ __DATA__
 DISTNAME: Test-Tech^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.09^
+VERSION : 0.10^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.08^
+PREVIOUS_RELEASE: 0.09^
 REVISION: H^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -635,10 +635,10 @@ t/Test/Tech/V001015/*
 ^
 
 PREREQ_PM: 
-'File::SmartNL' => 0,
-'File::Package' => 0,
-'File::TestPath' => 0,
-'Text::Scrub' => 0,
+'File::SmartNL' => '0',
+'File::Package' => '0',
+'File::TestPath' => '0',
+'Text::Scrub' => '0',
 ^
 
 TESTS: t/Test/Tech/Tech.t^
